@@ -1,4 +1,5 @@
 from requests import HTTPError
+import os
 
 
 def build_module_list(court_id):
@@ -10,6 +11,12 @@ def build_module_list(court_id):
     item is added to a list of modules.
 
     Returns either a list of modules or in the case of errors, an empty list.
+
+    *N.B.*: For the most part, this re-creates the `walk` function from the
+    pkgutil library. At some point, it's probably worth replacing this with
+    that. Live and learn.
+
+    https://docs.python.org/2/library/pkgutil.html#pkgutil.walk_packages
     """
     module_strings = []
 
@@ -44,6 +51,26 @@ def build_module_list(court_id):
     return module_strings
 
 
+def get_module_by_name(name):
+    db_root = os.path.abspath(
+        os.path.join(os.path.dirname(__file__), "..", "opinions")
+    )
+    for dirName, subdirList, fileList in os.walk(db_root):
+        for fname in fileList:
+            if "%s.py" % name == fname:
+                package, module = (
+                    dirName.split("/juriscraper/", 1)[1].replace("/", "."),
+                    fname[:-3],
+                )
+                juriscraper_module = __import__(
+                    "juriscraper.%s.%s" % (package, module),
+                    globals(),
+                    locals(),
+                    [module],
+                )
+                return juriscraper_module.Site()
+
+
 def site_yielder(iterable, mod):
 
     site = mod.Site()
