@@ -7,7 +7,7 @@ from lxml import html
 class Site(OpinionSite):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
-        self.url = "http://www.cadc.uscourts.gov/internet/opinions.nsf/uscadcopinions.xml"
+        self.url = "https://www.cadc.uscourts.gov/internet/opinions.nsf/uscadcopinions.xml"
         self.court_id = self.__module__
 
     def _get_case_names(self):
