@@ -9,5 +9,5 @@ class Site(calctapp_1st.Site):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.court_code = 'C'
-        self.division = '3rd App. Dist.'
+        self.court_code = "C"
+        self.division = "3rd App. Dist."
