@@ -8,6 +8,9 @@ class Site(OpinionSiteLinear):
         self.url = "http://nvcourts.gov/Supreme/Decisions/Unpublished_Orders/"
         self.status = "Published"
 
+        # HTTPS certificate is bad, but hopefully they'll fix it and we can remove the line below
+        self.disable_certificate_verification()
+
     def _process_html(self):
         table_row_path = '//table[@id="ctl00_ContentPlaceHolderContent_UnpublishedOrders_GridView1"]//tr[position()>1]'
         for row in self.html.xpath(table_row_path):
