@@ -57,7 +57,9 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
     ]
 
     def __init__(self, court_id, pacer_session=None):
-        super(AppellateDocketReport, self).__init__(court_id, pacer_session)
+        BaseDocketReport.__init__(self, court_id)
+        BaseReport.__init__(self, court_id, pacer_session)
+
         # Initialize the empty cache properties
         self._clear_caches()
         self._metadata = None
@@ -331,6 +333,9 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
 
     @property
     def metadata(self):
+        if self.is_valid is False:
+            return {}
+
         if self._metadata is not None:
             return self._metadata
 
