@@ -203,6 +203,7 @@ class BaseDocketReport(object):
         sep = u"FLP_SEPARATOR"
         html_text = tostring(element, encoding="unicode")
         html_text = re.sub(r"<br/?>", sep, html_text, flags=re.I)
+        html_text = re.sub(r"<p/?>", sep, html_text, flags=re.I)
         element = fromstring(html_text)
         text = force_unicode(" ".join(s for s in element.xpath(".//text()")))
         return [s.strip() for s in text.split(sep) if s]
@@ -740,7 +741,10 @@ class DocketReport(BaseDocketReport, BaseReport):
                     # No counts here. (Happens with terminated ones a lot.)
                     continue
                 criminal_data[u"complaints"].append(
-                    {u"name": complaint_name, u"disposition": disposition,}
+                    {
+                        u"name": complaint_name,
+                        u"disposition": disposition,
+                    }
                 )
 
     @staticmethod
@@ -1211,6 +1215,20 @@ class DocketReport(BaseDocketReport, BaseReport):
                     break
 
             if case_name is None:
+                # Try to get the case name from the party attribute. Use first
+                # plaintiff v. first defendant
+                plaintiff = None
+                defendant = None
+                for party in self.parties:
+                    if plaintiff is None and party["type"] == "Plaintiff":
+                        plaintiff = party["name"]
+                    elif defendant is None and party["type"] == "Defendant":
+                        defendant = party["name"]
+                if plaintiff and defendant:
+                    case_name = "%s v. %s" % (plaintiff, defendant)
+
+            if case_name is None:
+                # All parsing has failed. Give up.
                 case_name = u"Unknown Case Title"
 
         return clean_string(harmonize(case_name))
