@@ -4,6 +4,8 @@ import requests
 import tldextract
 from lxml import html
 
+from ..lib.exceptions import ParsingException
+
 
 def get_pacer_court_info():
     r = requests.get("https://court-version-scraper.herokuapp.com/courts.json")
@@ -162,6 +164,13 @@ def is_pdf(response):
     return False
 
 
+def is_text(response):
+    """Determines whether the item downloaded is a text file or something else."""
+    if ".txt" in response.headers.get("content-type", ""):
+        return True
+    return False
+
+
 def get_nonce_from_form(r):
     """Get a nonce value from a HTML response. Returns the first nonce that is
     found.
@@ -176,9 +185,13 @@ def get_nonce_from_form(r):
         # The action attr will be a value like:
         # ../cgi-bin/HistDocQry.pl?112801540788508-L_1_0-1
         # Split on the '?', and return the nonce.
-        path, nonce = attr.split("?")
-        if "-L_" in nonce:
-            return nonce
+        try:
+            path, nonce = attr.split("?")
+        except ValueError:
+            raise ParsingException("Didn't get nonce from PACER form.")
+        else:
+            if "-L_" in nonce:
+                return nonce
     return None
 
 
